[LON-CAPA-cvs] cvs: loncom /build make_domain_coordinator.pl

www lon-capa-cvs-allow@mail.lon-capa.org
Mon, 03 Mar 2008 15:25:02 -0000


www		Mon Mar  3 10:25:02 2008 EDT

  Modified files:              
    /loncom/build	make_domain_coordinator.pl 
  Log:
  Bug #5646 - make_domain_coordinator.pl generates wrong ownership of director
  
  
Index: loncom/build/make_domain_coordinator.pl
diff -u loncom/build/make_domain_coordinator.pl:1.14 loncom/build/make_domain_coordinator.pl:1.15
--- loncom/build/make_domain_coordinator.pl:1.14	Thu Jan  3 16:16:11 2008
+++ loncom/build/make_domain_coordinator.pl	Mon Mar  3 10:25:02 2008
@@ -11,7 +11,7 @@
 # The LearningOnline Network
 # make_domain_coordinator.pl - Make a domain coordinator on a system
 #
-# $Id: make_domain_coordinator.pl,v 1.14 2008/01/03 21:16:11 raeburn Exp $
+# $Id: make_domain_coordinator.pl,v 1.15 2008/03/03 15:25:02 www Exp $
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
 #
@@ -357,7 +357,11 @@
 open(OUT, ">$udpath/passwd");
 print(OUT 'unix:'."\n");
 close(OUT);
-`chown www:www $udpath/passwd`; # Must be writeable by httpd process.
+
+# Get permissions correct on udpath
+
+ print "Setting permissions on user data directories. This may take a moment, please be patient ...\n";
+`chown -R www:www /home/httpd/lonUsers/$domain` ; # Must be writeable by httpd process.
 
 =pod